@@ -1,7 +1,11 @@
-#ifndef SPVM_TYPEDEF_H
-#define SPVM_TYPEDEF_H
+#ifndef SPVM_TYPEDECL_H
+#define SPVM_TYPEDECL_H
 
 #include <stdint.h>
+#include <stddef.h>
+
+#include "spvm_list.h"
+#include "spvm_hash.h"
 
 // spvm_allow.h
 struct spvm_allow;
@@ -175,18 +179,6 @@ typedef struct spvm_descriptor SPVM_DESCRIPTOR;
 struct spvm_sub;
 typedef struct spvm_sub SPVM_SUB;
 
-// spvm_list.h
-struct spvm_list;
-typedef struct spvm_list SPVM_LIST;
-
-// spvm_hash_entry.h
-struct spvm_hash_entry;
-typedef struct spvm_hash_entry SPVM_HASH_ENTRY;
-
-// spvm_hash.h
-struct spvm_hash;
-typedef struct spvm_hash SPVM_HASH;
-
 union spvm_yystype;
 typedef union spvm_yystype SPVM_YYSTYPE;
 
